/* Generalized Harmonic Stepsize */
class HarmonicStepsize extends Stepsize 
{
  private int n;
  private double a; // Increase a to get slower convergence to 0
  private double alpha0 = 1; // First stepsize
  private double thetabar;

  HarmonicStepsize()
  {
	  n = 1;
	  a = 1;
	  alpha0 = 1;
	  thetabar = 0;
  }

  /* 
   * Get the stepsize for iteration n, and update state to be ready for the
   * next stepsize. 
   */
  public double Update(double sample)
  {
	  double alpha = alpha0 * a / (-1 + a + n++);
	  thetabar = (1-alpha) * thetabar + alpha * sample;
	  return thetabar;
  }
};
