import java.io.*;
import java.util.Date;
import java.text.DateFormat;

public class LogFile extends DataStream
{
  private int dataMask;
  private String name;
  private String file;
  private FileWriter fw;
  private BufferedWriter bw;
  private PrintWriter outFile;

  /*
   * The dataMask is a hexadecimal mask composed of dataClasss.  A set dataClass
   * implies that the corresponding datastream should be logged. 
   * 
   * Later we could move to a more generic facility in which you can add
   * datastreams, and each datastream that is added gets an identifier which
   * the owning code passes to the DataStream whenever the owning object writes
   * to the stream.  But right now its ok to compile in the identifiers.
   */
  public LogFile(String fileName, int dataMask)
  {
	  this.dataMask = dataMask;

	  file = fileName + ".out";
	  this.name = file;
	  try {
		  fw = new FileWriter(file);
		  bw = new BufferedWriter(fw);
		  outFile = new PrintWriter(bw);
	  } catch(IOException e) {
		  System.err.println("Could not open " + file);
		  outFile = null;
	  }
	  PostInit();
  }

  // Returns a string that tells us what dataclass we are in.  Note it appends
  // whitespace.
  private String Prefix(int dataClass)
  {
	  switch (dataClass) {
		  case T_BOSS: return "[T_BOSS] ";
		  case T_PEON: return "[T_PEON] ";
		  case T_VALU: return "[T_VALU] ";
		  case T_STEP: return "[T_STEP] ";
		  case T_SIM: return "[T_SIM] ";
		  case T_SYS: return "[T_SYS] ";
		  // otherwise just spit out the number.
		  // XXX better to spit it out in hex
		  default: return "[" + dataClass + "] "; 
	  }
  }

  // Logs a comment
  public void PutComment(int dataClass, String s)
  {
	  if ((dataClass & dataMask) == 0)
		  return;
	  outFile.println("# " + Prefix(dataClass) + s);
  }

  public void PutDataVector(int dataClass, double data[])
  {
	  if ((dataClass & dataMask) == 0)
		  return;

	  String s;
	  outFile.format(Prefix(dataClass));
	  for (int i=0; i < data.length; i++)
		  outFile.format("%.3f ", data[i]);
	  outFile.format("%n");
  }

  public void Cleanup() {
	  outFile.close();

	  /* Setting the outFile to null gives a more comprehensible error if
	   * someone tries to write after a cleanup.  
	   *
	   *
	   * To make this code even safer, we would check outFile == null
	   * beforewriting to it, and throw an exception that said you tried to
	   * write after calling Cleanup, instead of the more obtuse error
	   * message this code will actually throw.  
	   */
	  outFile = null;
  }
};
