import java.io.*;
import java.util.Date;
import java.text.DateFormat;

public class LoggedObject
{
  private String name;
  private String file;
  private FileWriter fw;
  private BufferedWriter bw;
  private PrintWriter outFile;

  protected LoggedObject(String name)
  {
	  this.name = name;
	  if (name == null) {
		  // Don't do any logging
		  outFile = null;
	  }
	  file = name + ".out";
	  try {
		  fw = new FileWriter(file);
		  bw = new BufferedWriter(fw);
		  outFile = new PrintWriter(bw);
	  } catch(IOException e) {
		  System.err.println("Could not open " + file);
		  outFile = null;
	  }

	  LogString("# " + name + " Log");
	  Date date = new Date();
	  LogString("# " + DateFormat.getDateTimeInstance(DateFormat.MEDIUM, DateFormat.LONG).format(date));
  }

  // Logs an output message to the log file
  protected void LogString(String s)
  {
	  if (outFile != null)
		  outFile.println(s);
  }

  protected void LogDataVector(double data[])
  {
	  if (outFile == null)
		  return;
	  String s;
	  for (int i=0; i < data.length; i++)
		  outFile.format("%.3f ", data[i]);
	  outFile.format("%n");
  }

  protected void LogData(double ... data) { LogDataVector(data); }

  // Java doesn't have destructors.  Put it in a regular method.
  public void cleanup() {
	  if (outFile != null)
		  outFile.close();
	  outFile = null;
  }
};
